@@ -5,7 +5,7 @@ namespace PhpParser\ErrorHandler;
 use PhpParser\Error;
 
 class ThrowingTest extends \PHPUnit\Framework\TestCase {
-    public function testHandleError() {
+    public function testHandleError(): void {
         $this->expectException(Error::class);
         $this->expectExceptionMessage('Test');
         $errorHandler = new Throwing();
