@@ -15,11 +15,11 @@ class DNumberTest extends \PHPUnit\Framework\TestCase {
         $this->assertInstanceOf(Echo_::class, $echo);
 
         /** @var Echo_ $echo */
-        $lLumber = $echo->exprs[0];
-        $this->assertInstanceOf(Float_::class, $lLumber);
+        $dnumber = $echo->exprs[0];
+        $this->assertInstanceOf(Float_::class, $dnumber);
 
         /** @var Float_ $dnumber */
-        $this->assertSame(1234.56, $lLumber->value);
-        $this->assertSame('1_234.56', $lLumber->getAttribute('rawValue'));
+        $this->assertSame(1234.56, $dnumber->value);
+        $this->assertSame('1_234.56', $dnumber->getAttribute('rawValue'));
     }
 }
