@@ -6,11 +6,11 @@ class MagicConstTest extends \PHPUnit\Framework\TestCase {
     /**
      * @dataProvider provideTestGetName
      */
-    public function testGetName(MagicConst $magicConst, $name) {
+    public function testGetName(MagicConst $magicConst, $name): void {
         $this->assertSame($name, $magicConst->getName());
     }
 
-    public function provideTestGetName() {
+    public static function provideTestGetName() {
         return [
             [new MagicConst\Class_(), '__CLASS__'],
             [new MagicConst\Dir(), '__DIR__'],
