@@ -6,7 +6,7 @@ use PhpParser\Node\Stmt\Echo_;
 use PhpParser\ParserFactory;
 
 class StringTest extends \PHPUnit\Framework\TestCase {
-    public function testRawValue() {
+    public function testRawValue(): void {
         $parser = (new ParserFactory())->createForNewestSupportedVersion();
         $nodes = $parser->parse('<?php echo "sequence \x41";');
 
@@ -25,7 +25,7 @@ class StringTest extends \PHPUnit\Framework\TestCase {
     /**
      * @dataProvider provideTestParseEscapeSequences
      */
-    public function testParseEscapeSequences($expected, $string, $quote) {
+    public function testParseEscapeSequences($expected, $string, $quote): void {
         $this->assertSame(
             $expected,
             String_::parseEscapeSequences($string, $quote)
@@ -35,14 +35,14 @@ class StringTest extends \PHPUnit\Framework\TestCase {
     /**
      * @dataProvider provideTestParse
      */
-    public function testCreate($expected, $string) {
+    public function testCreate($expected, $string): void {
         $this->assertSame(
             $expected,
             String_::parse($string)
         );
     }
 
-    public function provideTestParseEscapeSequences() {
+    public static function provideTestParseEscapeSequences() {
         return [
             ['"',              '\\"',              '"'],
             ['\\"',            '\\"',              '`'],
@@ -57,7 +57,7 @@ class StringTest extends \PHPUnit\Framework\TestCase {
         ];
     }
 
-    public function provideTestParse() {
+    public static function provideTestParse() {
         $tests = [
             ['A', '\'A\''],
             ['A', 'b\'A\''],
@@ -67,7 +67,7 @@ class StringTest extends \PHPUnit\Framework\TestCase {
             ['\'', '\'\\\'\''],
         ];
 
-        foreach ($this->provideTestParseEscapeSequences() as $i => $test) {
+        foreach (self::provideTestParseEscapeSequences() as $i => $test) {
             // skip second and third tests, they aren't for double quotes
             if ($i !== 1 && $i !== 2) {
                 $tests[] = [$test[0], '"' . $test[1] . '"'];
