@@ -9,7 +9,7 @@ use PhpParser\Node\Stmt\Else_;
 use PhpParser\Node\Stmt\If_;
 
 class NodeTraverserTest extends \PHPUnit\Framework\TestCase {
-    public function testNonModifying() {
+    public function testNonModifying(): void {
         $str1Node = new String_('Foo');
         $str2Node = new String_('Bar');
         $echoNode = new Node\Stmt\Echo_([$str1Node, $str2Node]);
@@ -32,7 +32,7 @@ class NodeTraverserTest extends \PHPUnit\Framework\TestCase {
         ], $visitor->trace);
     }
 
-    public function testModifying() {
+    public function testModifying(): void {
         $str1Node  = new String_('Foo');
         $str2Node  = new String_('Bar');
         $printNode = new Expr\Print_($str1Node);
@@ -75,7 +75,7 @@ class NodeTraverserTest extends \PHPUnit\Framework\TestCase {
         ], $visitor3->trace);
     }
 
-    public function testRemoveFromLeave() {
+    public function testRemoveFromLeave(): void {
         $str1Node = new String_('Foo');
         $str2Node = new String_('Bar');
 
@@ -99,7 +99,7 @@ class NodeTraverserTest extends \PHPUnit\Framework\TestCase {
         ], $visitor2->trace);
     }
 
-    public function testRemoveFromEnter() {
+    public function testRemoveFromEnter(): void {
         $str1Node = new String_('Foo');
         $str2Node = new String_('Bar');
 
@@ -122,7 +122,7 @@ class NodeTraverserTest extends \PHPUnit\Framework\TestCase {
         ], $visitor2->trace);
     }
 
-    public function testReturnArrayFromEnter() {
+    public function testReturnArrayFromEnter(): void {
         $str1Node = new String_('Str1');
         $str2Node = new String_('Str2');
         $str3Node = new String_('Str3');
@@ -147,7 +147,7 @@ class NodeTraverserTest extends \PHPUnit\Framework\TestCase {
         ], $visitor2->trace);
     }
 
-    public function testMerge() {
+    public function testMerge(): void {
         $strStart  = new String_('Start');
         $strMiddle = new String_('End');
         $strEnd    = new String_('Middle');
@@ -167,7 +167,7 @@ class NodeTraverserTest extends \PHPUnit\Framework\TestCase {
         );
     }
 
-    public function testInvalidDeepArray() {
+    public function testInvalidDeepArray(): void {
         $this->expectException(\LogicException::class);
         $this->expectExceptionMessage('Invalid node structure: Contains nested arrays');
         $strNode = new String_('Foo');
@@ -177,7 +177,7 @@ class NodeTraverserTest extends \PHPUnit\Framework\TestCase {
         $this->assertEquals($stmts, $traverser->traverse($stmts));
     }
 
-    public function testDontTraverseChildren() {
+    public function testDontTraverseChildren(): void {
         $strNode = new String_('str');
         $printNode = new Expr\Print_($strNode);
         $varNode = new Expr\Variable('foo');
@@ -212,7 +212,7 @@ class NodeTraverserTest extends \PHPUnit\Framework\TestCase {
         $this->assertEquals($expectedTrace, $visitor2->trace);
     }
 
-    public function testDontTraverseCurrentAndChildren() {
+    public function testDontTraverseCurrentAndChildren(): void {
         // print 'str'; -($foo * $foo);
         $strNode = new String_('str');
         $printNode = new Expr\Print_($strNode);
@@ -254,7 +254,7 @@ class NodeTraverserTest extends \PHPUnit\Framework\TestCase {
         ], $visitor2->trace);
     }
 
-    public function testStopTraversal() {
+    public function testStopTraversal(): void {
         $varNode1 = new Expr\Variable('a');
         $varNode2 = new Expr\Variable('b');
         $varNode3 = new Expr\Variable('c');
@@ -343,7 +343,7 @@ class NodeTraverserTest extends \PHPUnit\Framework\TestCase {
         ], $visitor->trace);
     }
 
-    public function testReplaceWithNull() {
+    public function testReplaceWithNull(): void {
         $one = new Int_(1);
         $else1 = new Else_();
         $else2 = new Else_();
@@ -381,7 +381,7 @@ class NodeTraverserTest extends \PHPUnit\Framework\TestCase {
         ], $visitor2->trace);
     }
 
-    public function testRemovingVisitor() {
+    public function testRemovingVisitor(): void {
         $visitor1 = new class () extends NodeVisitorAbstract {};
         $visitor2 = new class () extends NodeVisitorAbstract {};
         $visitor3 = new class () extends NodeVisitorAbstract {};
@@ -404,7 +404,7 @@ class NodeTraverserTest extends \PHPUnit\Framework\TestCase {
         $this->assertSame($postExpected, $getVisitors());
     }
 
-    public function testNoCloneNodes() {
+    public function testNoCloneNodes(): void {
         $stmts = [new Node\Stmt\Echo_([new String_('Foo'), new String_('Bar')])];
 
         $traverser = new NodeTraverser();
@@ -415,7 +415,7 @@ class NodeTraverserTest extends \PHPUnit\Framework\TestCase {
     /**
      * @dataProvider provideTestInvalidReturn
      */
-    public function testInvalidReturn($stmts, $visitor, $message) {
+    public function testInvalidReturn($stmts, $visitor, $message): void {
         $this->expectException(\LogicException::class);
         $this->expectExceptionMessage($message);
 
@@ -424,7 +424,7 @@ class NodeTraverserTest extends \PHPUnit\Framework\TestCase {
         $traverser->traverse($stmts);
     }
 
-    public function provideTestInvalidReturn() {
+    public static function provideTestInvalidReturn() {
         $num = new Node\Scalar\Int_(42);
         $expr = new Node\Stmt\Expression($num);
         $stmts = [$expr];
