@@ -1,6 +1,6 @@
 <?php
 
-error_reporting(E_ALL | E_STRICT);
+error_reporting(E_ALL);
 ini_set('short_open_tag', false);
 
 if ('cli' !== php_sapi_name()) {
@@ -121,6 +121,8 @@ switch ($testType) {
 | Zend.tests.type_declarations.intersection_types.parsing_comment
 # comments in property fetch syntax, not emulated on old PHP versions
 | Zend.tests.gh14961
+# harmless pretty print difference for clone($x, )
+| Zend.tests.clone.ast
 )\.phpt$~x', $file)) {
                 return null;
             }
